@@ -5,8 +5,8 @@ from django import forms
 
 class CommentForm(forms.Form):
 
-    user = forms.CharField(max_length=100)
-    comment = forms.CharField(max_length=1000, widget=forms.Textarea)
+    user = forms.CharField(max_length=100, widget=forms.TextInput(attrs={'class': 'input-xlarge'}))
+    comment = forms.CharField(max_length=1000, widget=forms.Textarea(attrs={'class': 'input-xlarge'}))
 
     one = forms.BooleanField(required=False)
     two = forms.BooleanField(required=False)
